@@ -40,9 +40,10 @@ static const zend_function_entry mysqlx_crud_operation_sortable_methods[] = {
 void
 mysqlx_register_crud_operation_sortable_interface(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* /*mysqlx_std_object_handlers*/)
 {
-	zend_class_entry tmp_ce;
-	INIT_NS_CLASS_ENTRY(tmp_ce, "mysql_xdevapi", "CrudOperationSortable", mysqlx_crud_operation_sortable_methods);
-	mysqlx_crud_operation_sortable_interface_entry = zend_register_internal_interface(&tmp_ce);
+	MYSQL_XDEVAPI_REGISTER_INTERFACE(
+		mysqlx_crud_operation_sortable_interface_entry,
+		"CrudOperationSortable",
+		mysqlx_crud_operation_sortable_methods);
 }
 
 void
