@@ -128,11 +128,11 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_doc_result, getWarningsCount)
 	RETVAL_LONG(0);
 
 	auto& data_object{ util::fetch_data_object<st_mysqlx_doc_result>(object_zv) };
-	size_t warning_count{ 0 };
+	std::size_t warning_count{ 0 };
 	const XMYSQLND_WARNING_LIST* const warnings = data_object.result->warnings;
 	/* Maybe check here if there was an error and throw an Exception or return a warning */
 	if (warnings) {
-		warning_count = warnings->m->count(warnings);
+		warning_count = warnings->count();
 	}
 	if (UNEXPECTED(warning_count >= ZEND_LONG_MAX)) {
 		ZVAL_NEW_STR(return_value, strpprintf(0, "%s", util::to_string(warning_count).c_str()));
@@ -159,10 +159,10 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_doc_result, getWarnings)
 	const XMYSQLND_WARNING_LIST * const warnings = data_object.result->warnings;
 	/* Maybe check here if there was an error and throw an Exception or return a warning */
 	if (warnings) {
-		const unsigned int count{warnings->m->count(warnings)};
-		array_init_size(return_value, count);
-		for (unsigned int i{0}; i < count; ++i) {
-			const XMYSQLND_WARNING warning = warnings->m->get_warning(warnings, i);
+		const std::size_t count{warnings->count()};
+		array_init_size(return_value, static_cast<uint32_t>(count));
+		for (std::size_t i{0}; i < count; ++i) {
+			const XMYSQLND_WARNING warning = warnings->get_warning(i);
 			util::zvalue warning_zv;
 			mysqlx_new_warning(warning_zv.ptr(), warning.message, warning.level, warning.code);
 
@@ -192,9 +192,9 @@ static const zend_function_entry mysqlx_doc_result_methods[] = {
 static zend_object_handlers mysqlx_object_doc_result_handlers;
 static HashTable mysqlx_doc_result_properties;
 
-const struct st_mysqlx_property_entry mysqlx_doc_result_property_entries[] =
+const st_mysqlx_property_entry mysqlx_doc_result_property_entries[] =
 {
-	{{nullptr,	0}, nullptr, nullptr}
+	{std::string_view{}, nullptr, nullptr}
 };
 
 static void
