@@ -18,13 +18,15 @@
 #ifndef MYSQLX_EXPRESSION_H
 #define MYSQLX_EXPRESSION_H
 
+#include "util/strings.h"
+
 namespace mysqlx {
 
 namespace devapi {
 
 zend_bool is_a_mysqlx_expression(const zval * const value);
 zval* get_mysqlx_expression(const zval * const object_zv);
-void mysqlx_new_expression(zval* return_value, const MYSQLND_CSTRING expression);
+void mysqlx_new_expression(zval* return_value, const util::string_view& expression);
 void mysqlx_register_expression_class(INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers);
 void mysqlx_unregister_expression_class(SHUTDOWN_FUNC_ARGS);
 
