@@ -194,7 +194,7 @@ exec_with_cb_handle_on_warning(
 	xmysqlnd_stmt * const /*stmt*/,
 	const enum xmysqlnd_stmt_warning_level /*level*/,
 	const unsigned int code,
-	const MYSQLND_CSTRING message)
+	const util::string_view& message)
 {
 	enum_hnd_func_status ret{HND_AGAIN};
 	st_xmysqlnd_exec_with_cb_ctx* ctx = (st_xmysqlnd_exec_with_cb_ctx*) context;
@@ -207,7 +207,7 @@ exec_with_cb_handle_on_warning(
 		zval return_value;
 
 		ZVAL_LONG(code_zv, code);
-		ZVAL_STRINGL(message_zv, message.s, message.l);
+		ZVAL_STRINGL(message_zv, message.data(), message.length());
 
 		ZVAL_COPY(user_context, ctx->ctx);
 
@@ -235,8 +235,8 @@ exec_with_cb_handle_on_error(
 	void * context,
 	xmysqlnd_stmt * const /*stmt*/,
 	const unsigned int code,
-	const MYSQLND_CSTRING sql_state,
-	const MYSQLND_CSTRING message)
+	const util::string_view& sql_state,
+	const util::string_view& message)
 {
 	enum_hnd_func_status ret{HND_PASS_RETURN_FAIL};
 	st_xmysqlnd_exec_with_cb_ctx* ctx = (st_xmysqlnd_exec_with_cb_ctx*) context;
@@ -250,8 +250,8 @@ exec_with_cb_handle_on_error(
 		zval return_value;
 
 		ZVAL_LONG(code_zv, code);
-		ZVAL_STRINGL(sql_state_zv, sql_state.s, sql_state.l);
-		ZVAL_STRINGL(message_zv, message.s, message.l);
+		ZVAL_STRINGL(sql_state_zv, sql_state.data(), sql_state.length());
+		ZVAL_STRINGL(message_zv, message.data(), message.length());
 
 		ZVAL_COPY(user_context, ctx->ctx);
 
@@ -371,11 +371,11 @@ mysqlx_fetch_data_with_callback(st_mysqlx_statement* object, st_xmysqlnd_exec_wi
 	const zend_bool on_rset_end_passed = ZEND_FCI_INITIALIZED(xmysqlnd_exec_with_cb_ctx->on_rset_end.fci);
 	const zend_bool on_stmt_ok_passed = ZEND_FCI_INITIALIZED(xmysqlnd_exec_with_cb_ctx->on_stmt_ok.fci);
 
-	const struct st_xmysqlnd_stmt_on_row_bind on_row = { exec_with_cb_handle_on_row, xmysqlnd_exec_with_cb_ctx };
-	const struct st_xmysqlnd_stmt_on_warning_bind on_warning = { exec_with_cb_handle_on_warning, xmysqlnd_exec_with_cb_ctx };
-	const struct st_xmysqlnd_stmt_on_error_bind on_error = { exec_with_cb_handle_on_error, xmysqlnd_exec_with_cb_ctx };
-	const struct st_xmysqlnd_stmt_on_result_end_bind on_resultset_end = { on_rset_end_passed? exec_with_cb_handle_on_resultset_end : nullptr, xmysqlnd_exec_with_cb_ctx };
-	const struct st_xmysqlnd_stmt_on_statement_ok_bind on_statement_ok = { on_stmt_ok_passed? exec_with_cb_handle_on_statement_ok : nullptr, xmysqlnd_exec_with_cb_ctx };
+	const st_xmysqlnd_stmt_on_row_bind on_row = { exec_with_cb_handle_on_row, xmysqlnd_exec_with_cb_ctx };
+	const st_xmysqlnd_stmt_on_warning_bind on_warning = { exec_with_cb_handle_on_warning, xmysqlnd_exec_with_cb_ctx };
+	const st_xmysqlnd_stmt_on_error_bind on_error = { exec_with_cb_handle_on_error, xmysqlnd_exec_with_cb_ctx };
+	const st_xmysqlnd_stmt_on_result_end_bind on_resultset_end = { on_rset_end_passed? exec_with_cb_handle_on_resultset_end : nullptr, xmysqlnd_exec_with_cb_ctx };
+	const st_xmysqlnd_stmt_on_statement_ok_bind on_statement_ok = { on_stmt_ok_passed? exec_with_cb_handle_on_statement_ok : nullptr, xmysqlnd_exec_with_cb_ctx };
 
 	DBG_ENTER("mysqlx_fetch_data_with_callback");
 
@@ -440,10 +440,10 @@ mysqlx_sql_stmt_on_warning(
 	xmysqlnd_stmt * const /*stmt*/,
 	const enum xmysqlnd_stmt_warning_level /*level*/,
 	const unsigned int /*code*/,
-	const MYSQLND_CSTRING /*message*/)
+	const util::string_view& /*message*/)
 {
 	DBG_ENTER("mysqlx_sql_stmt_on_warning");
-	//php_error_docref(nullptr, E_WARNING, "[%d] %*s", code, message.l, message.s);
+	//php_error_docref(nullptr, E_WARNING, "[%d] %*s", code, message.length(), message.data());
 	DBG_RETURN(HND_AGAIN);
 }
 
@@ -452,8 +452,8 @@ mysqlx_sql_stmt_on_error(
 	void * /*context*/,
 	xmysqlnd_stmt * const /*stmt*/,
 	const unsigned int code,
-	const MYSQLND_CSTRING sql_state,
-	const MYSQLND_CSTRING message)
+	const util::string_view& sql_state,
+	const util::string_view& message)
 {
 	DBG_ENTER("mysqlx_sql_stmt_on_error");
 	mysqlx_new_exception(code, sql_state, message);
@@ -473,8 +473,8 @@ mysqlx_sql_statement_get_results(
 			DBG_INF("ASYNC");
 			RETVAL_BOOL(PASS == object->send_query_status);
 		} else {
-			const struct st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
-			const struct st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
+			const st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
+			const st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
 			XMYSQLND_STMT_RESULT * result;
 			if (object->execute_flags & MYSQLX_EXECUTE_FLAG_BUFFERED) {
 				result = stmt->get_buffered_result(stmt, &object->has_more_results, on_warning, on_error, nullptr, nullptr);
@@ -616,8 +616,8 @@ static void mysqlx_sql_statement_read_result(INTERNAL_FUNCTION_PARAMETERS, zend_
 		if (use_callbacks) {
 			RETVAL_BOOL(PASS == mysqlx_fetch_data_with_callback(&data_object, &xmysqlnd_exec_with_cb_ctx));
 		} else {
-			const struct st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
-			const struct st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
+			const st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
+			const st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
 			XMYSQLND_STMT_RESULT * result;
 
 			if (data_object.execute_flags & MYSQLX_EXECUTE_FLAG_BUFFERED) {
@@ -664,9 +664,9 @@ static const zend_function_entry mysqlx_sql_statement_methods[] = {
 static zend_object_handlers mysqlx_object_sql_statement_handlers;
 static HashTable mysqlx_sql_statement_properties;
 
-const struct st_mysqlx_property_entry mysqlx_sql_statement_property_entries[] =
+const st_mysqlx_property_entry mysqlx_sql_statement_property_entries[] =
 {
-	{{nullptr,	0}, nullptr, nullptr}
+	{std::string_view{}, nullptr, nullptr}
 };
 
 
@@ -715,7 +715,7 @@ mysqlx_unregister_sql_statement_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 }
 
 void
-mysqlx_new_sql_stmt(zval* return_value, xmysqlnd_stmt* stmt, const MYSQLND_CSTRING namespace_, const MYSQLND_CSTRING query)
+mysqlx_new_sql_stmt(zval* return_value, xmysqlnd_stmt* stmt, const std::string_view& namespace_, const util::string_view& query)
 {
 	DBG_ENTER("mysqlx_new_sql_stmt");
 
@@ -774,8 +774,8 @@ mysqlx_statement_execute_read_response(const st_mysqlx_object* const mysqlx_obje
 			DBG_INF("ASYNC");
 			RETVAL_BOOL(PASS == object->send_query_status);
 		} else {
-				const struct st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
-				const struct st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
+				const st_xmysqlnd_stmt_on_warning_bind on_warning = { mysqlx_sql_stmt_on_warning, nullptr };
+				const st_xmysqlnd_stmt_on_error_bind on_error = { mysqlx_sql_stmt_on_error, nullptr };
 				XMYSQLND_STMT_RESULT * result;
 				if (object->execute_flags & MYSQLX_EXECUTE_FLAG_BUFFERED) {
 					result = stmt->get_buffered_result(stmt,
@@ -899,9 +899,9 @@ static const zend_function_entry mysqlx_statement_methods[] = {
 static zend_object_handlers mysqlx_object_statement_handlers;
 static HashTable mysqlx_statement_properties;
 
-const struct st_mysqlx_property_entry mysqlx_statement_property_entries[] =
+const st_mysqlx_property_entry mysqlx_statement_property_entries[] =
 {
-	{{nullptr,	0}, nullptr, nullptr}
+	{std::string_view{}, nullptr, nullptr}
 };
 
 
