@@ -112,10 +112,10 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__select, where)
 	DBG_ENTER("mysqlx_table__select::where");
 
 	zval* object_zv{nullptr};
-	MYSQLND_CSTRING where_expr = {nullptr, 0};
+	util::param_string where_expr;
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Os",
 												&object_zv, mysqlx_table__select_class_entry,
-												&(where_expr.s), &(where_expr.l)))
+												&where_expr.str, &where_expr.len))
 	{
 		DBG_VOID_RETURN;
 	}
@@ -124,8 +124,8 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__select, where)
 
 	RETVAL_FALSE;
 
-	if (data_object.table && where_expr.s && where_expr.l) {
-		if (PASS == xmysqlnd_crud_table_select__set_criteria(data_object.crud_op, where_expr)) {
+	if (!where_expr.empty()) {
+		if (PASS == xmysqlnd_crud_table_select__set_criteria(data_object.crud_op, where_expr.to_view())) {
 			ZVAL_COPY(return_value, object_zv);
 		}
 	}
@@ -178,7 +178,7 @@ mysqlx_table__select__add_sort_or_grouping(INTERNAL_FUNCTION_PARAMETERS, const u
 		{
 		case IS_STRING:
 			{
-				const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL(sort_expr[i]), Z_STRLEN(sort_expr[i]) };
+				const util::string_view sort_expr_str{ Z_STRVAL(sort_expr[i]), Z_STRLEN(sort_expr[i]) };
 				if (ADD_SORT == op_type) {
 					if (PASS == xmysqlnd_crud_table_select__add_orderby(data_object.crud_op, sort_expr_str)) {
 						ZVAL_COPY(return_value, object_zv);
@@ -196,7 +196,7 @@ mysqlx_table__select__add_sort_or_grouping(INTERNAL_FUNCTION_PARAMETERS, const u
 				enum_func_status ret{FAIL};
 				MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL(sort_expr[i]), entry) {
 					ret = FAIL;
-					const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL_P(entry), Z_STRLEN_P(entry) };
+					const util::string_view sort_expr_str{ Z_STRVAL_P(entry), Z_STRLEN_P(entry) };
 					if (Z_TYPE_P(entry) != IS_STRING) {
 						RAISE_EXCEPTION(err_msg_wrong_param_1);
 						DBG_VOID_RETURN;
@@ -243,10 +243,10 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__select, having)
 	DBG_ENTER("mysqlx_table__select::having");
 
 	zval* object_zv{nullptr};
-	MYSQLND_CSTRING search_condition = {nullptr, 0};
+	util::param_string search_condition;
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Os",
 												&object_zv, mysqlx_table__select_class_entry,
-												&(search_condition.s), &(search_condition.l)))
+												&search_condition.str, &search_condition.len))
 	{
 		DBG_VOID_RETURN;
 	}
@@ -256,7 +256,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__select, having)
 	RETVAL_FALSE;
 
 	if (data_object.crud_op && data_object.table) {
-		if (PASS == xmysqlnd_crud_table_select__set_having(data_object.crud_op, search_condition)) {
+		if (PASS == xmysqlnd_crud_table_select__set_having(data_object.crud_op, search_condition.to_view())) {
 			ZVAL_COPY(return_value, object_zv);
 		}
 	}
@@ -348,7 +348,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__select, bind)
 		zval* val{nullptr};
 		MYSQLX_HASH_FOREACH_STR_KEY_VAL(bind_variables, key, val) {
 			if (key) {
-				const MYSQLND_CSTRING variable = { ZSTR_VAL(key), ZSTR_LEN(key) };
+				const util::string_view variable{ ZSTR_VAL(key), ZSTR_LEN(key) };
 				if (FAIL == xmysqlnd_crud_table_select__bind_value(data_object.crud_op, variable, val)) {
 					RAISE_EXCEPTION(err_msg_bind_fail);
 					DBG_VOID_RETURN;
@@ -478,8 +478,8 @@ mysqlx_table__select_property__name(const st_mysqlx_object* obj, zval* return_va
 {
 	const st_mysqlx_table__select* object = (const st_mysqlx_table__select* ) (obj->ptr);
 	DBG_ENTER("mysqlx_table__select_property__name");
-	if (object->table && object->table->get_name().s) {
-		ZVAL_STRINGL(return_value, object->table->get_name().s, object->table->get_name().l);
+	if (object->table && !object->table->get_name().empty()) {
+		ZVAL_STRINGL(return_value, object->table->get_name().data(), object->table->get_name().length());
 	} else {
 		/*
 		  This means EG(uninitialized_value). If we return just return_value, this is an UNDEF-ed value
@@ -498,12 +498,12 @@ mysqlx_table__select_property__name(const st_mysqlx_object* obj, zval* return_va
 static zend_object_handlers mysqlx_object_table__select_handlers;
 static HashTable mysqlx_table__select_properties;
 
-const struct st_mysqlx_property_entry mysqlx_table__select_property_entries[] =
+const st_mysqlx_property_entry mysqlx_table__select_property_entries[] =
 {
 #if 0
-	{{"name",	sizeof("name") - 1}, mysqlx_table__select_property__name,	nullptr},
+	{std::string_view("name"), mysqlx_table__select_property__name,	nullptr},
 #endif
-	{{nullptr,	0}, nullptr, nullptr}
+	{std::string_view{}, nullptr, nullptr}
 };
 
 static void
@@ -562,8 +562,8 @@ mysqlx_new_table__select(
 		util::init_object<st_mysqlx_table__select>(mysqlx_table__select_class_entry, return_value) };
 	data_object.table = table->get_reference();
 	data_object.crud_op = xmysqlnd_crud_table_select__create(
-		mnd_str2c(data_object.table->get_schema()->get_name()),
-		mnd_str2c(data_object.table->get_name()),
+		data_object.table->get_schema()->get_name(),
+		data_object.table->get_name(),
 		columns,
 		num_of_columns);
 	DBG_VOID_RETURN;
