@@ -18,13 +18,15 @@
 #ifndef MYSQLX_WARNING_H
 #define MYSQLX_WARNING_H
 
+#include "util/strings.h"
+
 namespace mysqlx {
 
 namespace devapi {
 
 void mysqlx_register_warning_class(INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers);
 void mysqlx_unregister_warning_class(SHUTDOWN_FUNC_ARGS);
-void mysqlx_new_warning(zval* return_value, const MYSQLND_CSTRING msg, unsigned int level, const unsigned int code);
+void mysqlx_new_warning(zval* return_value, const util::string& msg, unsigned int level, const unsigned int code);
 
 } // namespace devapi
 
