@@ -32,14 +32,14 @@ namespace util {
 namespace
 {
 
-const char* const General_sql_state{ GENERAL_SQL_STATE };
-const char* const Unknown_error_message{ "Unknown error" };
+constexpr string_view General_sql_state{ "HY000" };
+constexpr string_view Unknown_error_message{ "Unknown error" };
 
 const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg{
 	{ xdevapi_exception::Code::fetch_fail, "Couldn't fetch data" },
 	{ xdevapi_exception::Code::meta_fail, "Unable to extract metadata" },
 	{ xdevapi_exception::Code::add_doc, "Error adding document" },
-	{ xdevapi_exception::Code::json_fail, "Error serializing document to JSON" },
+	{ xdevapi_exception::Code::json_fail, "Error serializing document to JSON, code:" },
 	{ xdevapi_exception::Code::add_index_field_err, "Error while adding an index field" },
 	{ xdevapi_exception::Code::add_orderby_fail, "Error while adding a orderby expression" },
 	{ xdevapi_exception::Code::add_sort_fail, "Error while adding a sort expression" },
@@ -84,25 +84,25 @@ const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg{
 	{ xdevapi_exception::Code::invalid_auth_mechanism, "Invalid authentication mechanism" },
 	{ xdevapi_exception::Code::unknown_lock_waiting_option, "Unknown lock waiting option" },
 	{ xdevapi_exception::Code::schema_creation_failed, "Unable to create the schema object" },
-	{ xdevapi_exception::Code::table_creation_failed, "Unable to create the table object"},
+	{ xdevapi_exception::Code::table_creation_failed, "Unable to create the table object" },
 	{ xdevapi_exception::Code::invalid_timeout,
-		"TypeError: The connection timeout value must be a positive integer (including 0)."},
+		"TypeError: The connection timeout value must be a positive integer (including 0)." },
 	{ xdevapi_exception::Code::timeout_exceeded,
-		"TimeoutError: Connection attempt to the server was aborted. Timeout was exceeded."},
-	{ xdevapi_exception::Code::invalid_argument, "Invalid argument."},
-	{ xdevapi_exception::Code::connection_failure, "Connection failure."},
-	{ xdevapi_exception::Code::authentication_failure, "Authentication failure."},
-	{ xdevapi_exception::Code::runtime_error, "Run-time error."},
-	{ xdevapi_exception::Code::session_closed, "Session closed."},
+		"TimeoutError: Connection attempt to the server was aborted. Timeout was exceeded." },
+	{ xdevapi_exception::Code::invalid_argument, "Invalid argument." },
+	{ xdevapi_exception::Code::connection_failure, "Connection failure." },
+	{ xdevapi_exception::Code::authentication_failure, "Authentication failure." },
+	{ xdevapi_exception::Code::runtime_error, "Run-time error." },
+	{ xdevapi_exception::Code::session_closed, "Session closed." },
 	{ xdevapi_exception::Code::offset_without_limit_not_allowed,
-		"The use of 'offset' without 'limit' is not allowed"},
+		"The use of 'offset' without 'limit' is not allowed" },
 	{ xdevapi_exception::Code::ps_unknown_message,
-		"Attempting to prepare a statement for an unknown message!"},
+		"Attempting to prepare a statement for an unknown message!" },
 	{ xdevapi_exception::Code::ps_limit_not_supported,
-		"Limit not supported for this message, prepared statement failed!"},
-	{ xdevapi_exception::Code::session_reset_failure, "Session reset failure."},
+		"Limit not supported for this message, prepared statement failed!" },
+	{ xdevapi_exception::Code::session_reset_failure, "Session reset failure." },
 	{ xdevapi_exception::Code::conn_attrib_wrong_type,
-		"The value of \"connection-attributes\" must be either a boolean or a list of key-value pairs"},
+		"The value of \"connection-attributes\" must be either a boolean or a list of key-value pairs" },
 	{ xdevapi_exception::Code::conn_attrib_dup_key,
 		"Duplicate key used in the \"connection-attributes\" option." },
 	{ xdevapi_exception::Code::unknown_client_conn_option,
@@ -117,34 +117,42 @@ const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg{
 	{ xdevapi_exception::Code::cannot_setup_tls,
 		"Negative response from the server, not able to setup TLS." },
 	{ xdevapi_exception::Code::no_valid_cipher_in_list,
-		"No valid cipher found in the ssl ciphers list."},
+		"No valid cipher found in the ssl ciphers list." },
 	{ xdevapi_exception::Code::no_valid_ciphersuite_in_list,
-		"No valid cipher suite found in the tls ciphersuites list."},
+		"No valid cipher suite found in the tls ciphersuites list." },
 	{ xdevapi_exception::Code::port_nbr_not_allowed_with_srv_uri,
-		"Specifying a port number with DNS SRV lookup is not allowed"},
+		"Specifying a port number with DNS SRV lookup is not allowed" },
 	{ xdevapi_exception::Code::provided_invalid_uri,
-		"Incorrect URI string provided"},
+		"Incorrect URI string provided" },
 	{ xdevapi_exception::Code::unix_socket_not_allowed_with_srv,
-		"Using Unix domain sockets with DNS SRV lookup is not allowed"},
+		"Using Unix domain sockets with DNS SRV lookup is not allowed" },
 	{ xdevapi_exception::Code::url_list_not_allowed,
-		"URI with a list of URL not allowed."},
-	{ xdevapi_exception::Code::out_of_range, "out of range"},
-	{ xdevapi_exception::Code::json_parse_error, "json parse error"},
+		"URI with a list of URL not allowed." },
+	{ xdevapi_exception::Code::out_of_range, "out of range" },
+	{ xdevapi_exception::Code::json_parse_error, "json parse error, code:" },
 	{ xdevapi_exception::Code::compression_not_supported,
-		"Compression requested but the server does not support it."},
+		"Compression requested but the server does not support it." },
 	{ xdevapi_exception::Code::compressor_not_available,
-		"To enable given compression algorithm please build mysql_xdevapi with proper switch like --with-(zlib|lz4|zstd)=[DIR]."},
+		"To enable given compression algorithm please build mysql_xdevapi with proper switch like --with-(zlib|lz4|zstd)=[DIR]." },
 	{ xdevapi_exception::Code::compression_negotiation_failure,
-		"Compression requested but the compression algorithm negotiation failed."},
+		"Compression requested but the compression algorithm negotiation failed." },
+	{ xdevapi_exception::Code::compression_invalid_algorithm_name, "Invalid algorithm name:" },
+	{ xdevapi_exception::Code::object_property_not_exist,
+		"Object property doesn't exist:" },
+	{ xdevapi_exception::Code::object_property_invalid_type,
+		"Invalid type of object property, expected type is:" },
+	{ xdevapi_exception::Code::json_object_expected,
+		"Invalid format of document, JSON object expected: " },
+	{ xdevapi_exception::Code::json_array_expected,
+		"Invalid format of document, JSON array expected: " },
 };
 
-/* {{{ to_sql_state */
-string to_sql_state(const string& sql_state)
+string_view to_sql_state(const string_view& sql_state)
 {
 	return sql_state.empty() ? General_sql_state : sql_state;
 }
 
-string to_error_msg(xdevapi_exception::Code code, const string& what)
+string to_error_msg(xdevapi_exception::Code code, const string_view& what)
 {
 	string msg;
 	auto it{ code_to_err_msg.find(code) };
@@ -157,10 +165,10 @@ string to_error_msg(xdevapi_exception::Code code, const string& what)
 		msg += what;
 	}
 
-	return msg.empty() ? Unknown_error_message : msg;
+	return msg.empty() ? string{Unknown_error_message} : msg;
 }
 
-string to_error_msg(unsigned int code, const string& what)
+string to_error_msg(unsigned int code, const string_view& what)
 {
 	return to_error_msg(static_cast<xdevapi_exception::Code>(code), what);
 }
@@ -170,36 +178,21 @@ string to_error_msg(unsigned int code, const string& what)
 //------------------------------------------------------------------------------
 
 xdevapi_exception::xdevapi_exception(Code code)
-	: xdevapi_exception(code, nullptr)
+	: xdevapi_exception(code, string_view{})
 {
 }
 
-xdevapi_exception::xdevapi_exception(Code code, const string& msg)
-	: xdevapi_exception(static_cast<unsigned int>(code), msg)
+xdevapi_exception::xdevapi_exception(Code code, int error_number)
+	: xdevapi_exception(code, std::to_string(error_number))
 {
 }
 
-xdevapi_exception::xdevapi_exception(Code code, const char* msg)
-	: xdevapi_exception(static_cast<unsigned int>(code), General_sql_state, msg)
+xdevapi_exception::xdevapi_exception(Code code, const string_view& msg)
+	: xdevapi_exception(static_cast<int>(code), General_sql_state, msg)
 {
 }
 
-xdevapi_exception::xdevapi_exception(Code code, const std::string& msg)
-	: xdevapi_exception(code, util::to_string(msg))
-{
-}
-
-xdevapi_exception::xdevapi_exception(unsigned int code, const string& msg)
-	: xdevapi_exception(code, General_sql_state, msg)
-{
-}
-
-xdevapi_exception::xdevapi_exception(unsigned int code, const char* sql_state, const char* msg)
-	: xdevapi_exception(code, to_string(sql_state), to_string(msg))
-{
-}
-
-xdevapi_exception::xdevapi_exception(unsigned int code, const string& sql_state, const string& msg)
+xdevapi_exception::xdevapi_exception(unsigned int code, const string_view& sql_state, const string_view& msg)
 	: std::runtime_error(prepare_reason_msg(code, sql_state, msg).c_str())
 	, code(code)
 {
@@ -253,7 +246,7 @@ void raise_unknown_exception()
 
 //------------------------------------------------------------------------------
 
-string prepare_reason_msg(unsigned int code, const string& sql_state, const string& what)
+string prepare_reason_msg(unsigned int code, const string_view& sql_state, const string_view& what)
 {
 	ostringstream os;
 	os << '[' << code << "][" << to_sql_state(sql_state) << "] " << to_error_msg(code, what);
@@ -261,11 +254,6 @@ string prepare_reason_msg(unsigned int code, const string& sql_state, const stri
 	return reason;
 }
 
-string prepare_reason_msg(unsigned int code, const char* sql_state, const char* what)
-{
-	return prepare_reason_msg(code, to_string(sql_state), to_string(what));
-}
-
 void log_warning(const string& msg)
 {
 	php_error_docref(nullptr, E_WARNING, "%s", msg.c_str());
@@ -274,7 +262,7 @@ void log_warning(const string& msg)
 void set_error_info(util::xdevapi_exception::Code code, MYSQLND_ERROR_INFO* error_info)
 {
 	error_info->error_no = static_cast<unsigned int>(code);
-	strcpy(error_info->sqlstate, General_sql_state);
+	strcpy(error_info->sqlstate, General_sql_state.data());
 	error_info->error[0] = 0;
 }
 
