@@ -28,7 +28,7 @@ namespace drv {
 
 typedef struct st_xmysqlnd_crud_table_op__insert XMYSQLND_CRUD_TABLE_OP__INSERT;
 
-XMYSQLND_CRUD_TABLE_OP__INSERT * xmysqlnd_crud_table_insert__create(const MYSQLND_CSTRING schema, const MYSQLND_CSTRING table, zval * columns, const int num_of_columns);
+XMYSQLND_CRUD_TABLE_OP__INSERT * xmysqlnd_crud_table_insert__create(const util::string& schema, const util::string& table, zval * columns, const int num_of_columns);
 void xmysqlnd_crud_table_insert__destroy(XMYSQLND_CRUD_TABLE_OP__INSERT * obj);
 enum_func_status xmysqlnd_crud_table_insert__add_row(XMYSQLND_CRUD_TABLE_OP__INSERT * obj, zval * values_zv);
 enum_func_status xmysqlnd_crud_table_insert__finalize_bind(XMYSQLND_CRUD_TABLE_OP__INSERT * obj);
@@ -38,29 +38,31 @@ zend_bool xmysqlnd_crud_table_insert__is_initialized(XMYSQLND_CRUD_TABLE_OP__INS
 
 typedef struct st_xmysqlnd_crud_table_op__delete XMYSQLND_CRUD_TABLE_OP__DELETE;
 
-XMYSQLND_CRUD_TABLE_OP__DELETE * xmysqlnd_crud_table_delete__create(const MYSQLND_CSTRING schema, const MYSQLND_CSTRING table);
+XMYSQLND_CRUD_TABLE_OP__DELETE * xmysqlnd_crud_table_delete__create(
+	const util::string& schema,
+	const util::string& table);
 void xmysqlnd_crud_table_delete__destroy(XMYSQLND_CRUD_TABLE_OP__DELETE * obj);
-enum_func_status xmysqlnd_crud_table_delete__set_criteria(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const MYSQLND_CSTRING criteria);
+enum_func_status xmysqlnd_crud_table_delete__set_criteria(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const util::string_view& criteria);
 enum_func_status xmysqlnd_crud_table_delete__set_limit(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const size_t limit);
-enum_func_status xmysqlnd_crud_table_delete__bind_value(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const MYSQLND_CSTRING name, zval * value);
-enum_func_status xmysqlnd_crud_table_delete__add_orderby(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const MYSQLND_CSTRING orderby);
+enum_func_status xmysqlnd_crud_table_delete__bind_value(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const util::string_view& name, zval * value);
+enum_func_status xmysqlnd_crud_table_delete__add_orderby(XMYSQLND_CRUD_TABLE_OP__DELETE * obj, const util::string_view& orderby);
 enum_func_status xmysqlnd_crud_table_delete__finalize_bind(XMYSQLND_CRUD_TABLE_OP__DELETE * obj);
 struct st_xmysqlnd_pb_message_shell xmysqlnd_crud_table_delete__get_protobuf_message(XMYSQLND_CRUD_TABLE_OP__DELETE * obj);
 zend_bool xmysqlnd_crud_table_delete__is_initialized(XMYSQLND_CRUD_TABLE_OP__DELETE * obj);
 
 
 typedef struct st_xmysqlnd_crud_table_op__update XMYSQLND_CRUD_TABLE_OP__UPDATE;
-XMYSQLND_CRUD_TABLE_OP__UPDATE * xmysqlnd_crud_table_update__create(const MYSQLND_CSTRING schema, const MYSQLND_CSTRING table);
+XMYSQLND_CRUD_TABLE_OP__UPDATE * xmysqlnd_crud_table_update__create(const util::string& schema, const util::string& table);
 void xmysqlnd_crud_table_update__destroy(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj);
-enum_func_status xmysqlnd_crud_table_update__set_criteria(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const MYSQLND_CSTRING criteria);
+enum_func_status xmysqlnd_crud_table_update__set_criteria(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const util::string_view& criteria);
 enum_func_status xmysqlnd_crud_table_update__set_limit(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const size_t limit);
 enum_func_status xmysqlnd_crud_table_update__set_offset(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const size_t offset);
-enum_func_status xmysqlnd_crud_table_update__bind_value(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const MYSQLND_CSTRING name, zval * value);
-enum_func_status xmysqlnd_crud_table_update__add_orderby(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const MYSQLND_CSTRING orderby);
+enum_func_status xmysqlnd_crud_table_update__bind_value(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const util::string_view& name, zval * value);
+enum_func_status xmysqlnd_crud_table_update__add_orderby(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const util::string_view& orderby);
 
-//enum_func_status xmysqlnd_crud_table_update__unset(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const MYSQLND_CSTRING path);
+//enum_func_status xmysqlnd_crud_table_update__unset(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj, const util::string_view& path);
 enum_func_status xmysqlnd_crud_table_update__set(XMYSQLND_CRUD_TABLE_OP__UPDATE * obj,
-													  const MYSQLND_CSTRING path,
+													  const util::string_view& path,
 													  const zval * const value,
 													  const zend_bool is_expression,
 													  const zend_bool is_document);
@@ -70,17 +72,17 @@ zend_bool xmysqlnd_crud_table_update__is_initialized(XMYSQLND_CRUD_TABLE_OP__UPD
 
 
 typedef struct st_xmysqlnd_crud_table_op__select XMYSQLND_CRUD_TABLE_OP__SELECT;
-XMYSQLND_CRUD_TABLE_OP__SELECT * xmysqlnd_crud_table_select__create(const MYSQLND_CSTRING schema, const MYSQLND_CSTRING table, zval * columns,const int num_of_columns);
+XMYSQLND_CRUD_TABLE_OP__SELECT * xmysqlnd_crud_table_select__create(const util::string& schema, const util::string& table, zval * columns,const int num_of_columns);
 void xmysqlnd_crud_table_select__destroy(XMYSQLND_CRUD_TABLE_OP__SELECT * obj);
-enum_func_status xmysqlnd_crud_table_select__set_criteria(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const MYSQLND_CSTRING criteria);
+enum_func_status xmysqlnd_crud_table_select__set_criteria(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const util::string_view& criteria);
 enum_func_status xmysqlnd_crud_table_select__set_limit(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const size_t limit);
 enum_func_status xmysqlnd_crud_table_select__set_offset(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const size_t offset);
-enum_func_status xmysqlnd_crud_table_select__bind_value(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const MYSQLND_CSTRING name, zval * value);
-enum_func_status xmysqlnd_crud_table_select__add_orderby(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const MYSQLND_CSTRING orderby);
-enum_func_status xmysqlnd_crud_table_select__add_grouping(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const MYSQLND_CSTRING search_field);
-enum_func_status xmysqlnd_crud_table_select__set_having(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const MYSQLND_CSTRING criteria);
+enum_func_status xmysqlnd_crud_table_select__bind_value(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const util::string_view& name, zval * value);
+enum_func_status xmysqlnd_crud_table_select__add_orderby(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const util::string_view& orderby);
+enum_func_status xmysqlnd_crud_table_select__add_grouping(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const util::string_view& search_field);
+enum_func_status xmysqlnd_crud_table_select__set_having(XMYSQLND_CRUD_TABLE_OP__SELECT * obj, const util::string_view& criteria);
 enum_func_status xmysqlnd_crud_table_select__set_column(XMYSQLND_CRUD_TABLE_OP__SELECT * obj,
-														   const MYSQLND_CSTRING column,
+														   const util::string_view& column,
 														   const zend_bool is_expression,
 														   const zend_bool allow_alias);
 enum_func_status xmysqlnd_crud_table_select__finalize_bind(XMYSQLND_CRUD_TABLE_OP__SELECT * obj);
@@ -93,7 +95,7 @@ enum_func_status xmysqlnd_crud_table_select_set_lock_waiting_option(XMYSQLND_CRU
 
 
 typedef struct st_xmysqlnd_stmt_op__execute XMYSQLND_STMT_OP__EXECUTE;
-XMYSQLND_STMT_OP__EXECUTE * xmysqlnd_stmt_execute__create(const MYSQLND_CSTRING namespace_, const MYSQLND_CSTRING stmt);
+XMYSQLND_STMT_OP__EXECUTE * xmysqlnd_stmt_execute__create(const std::string_view& namespace_, const util::string_view& stmt);
 void xmysqlnd_stmt_execute__destroy(XMYSQLND_STMT_OP__EXECUTE * obj);
 zend_bool xmysqlnd_stmt_execute__is_initialized(XMYSQLND_STMT_OP__EXECUTE * obj);
 enum_func_status xmysqlnd_stmt_execute__bind_one_param(XMYSQLND_STMT_OP__EXECUTE * obj, const unsigned int param_no, const zval * param_zv);
@@ -112,14 +114,14 @@ struct st_xmysqlnd_crud_table_op__insert
 	uint32_t ps_message_id;
 
 	st_xmysqlnd_crud_table_op__insert(
-		const MYSQLND_CSTRING & schema,
-		const MYSQLND_CSTRING & object_name,
+		const util::string& schema,
+		const util::string_view& object_name,
 		zval * columns_zv,
 		const int num_of_columns) :
 		ps_message_id{ 0 }
 	{
-		message.mutable_collection()->set_schema(schema.s, schema.l);
-		message.mutable_collection()->set_name(object_name.s, object_name.l);
+		message.mutable_collection()->set_schema(schema.c_str(), schema.length());
+		message.mutable_collection()->set_name(object_name.data(), object_name.length());
 		message.set_data_model(Mysqlx::Crud::TABLE);
 
 		add_columns(columns_zv,num_of_columns);
@@ -149,14 +151,14 @@ struct st_xmysqlnd_crud_table_op__select
 	uint32_t ps_message_id;
 
 	st_xmysqlnd_crud_table_op__select(
-		const MYSQLND_CSTRING & schema,
-		const MYSQLND_CSTRING & object_name,
+		const util::string& schema,
+		const util::string_view& object_name,
 		zval * columns,
 		const int num_of_columns) :
 		ps_message_id{ 0 }
 	{
-		message.mutable_collection()->set_schema(schema.s, schema.l);
-		message.mutable_collection()->set_name(object_name.s, object_name.l);
+		message.mutable_collection()->set_schema(schema.c_str(), schema.length());
+		message.mutable_collection()->set_name(object_name.data(), object_name.length());
 		message.set_data_model(Mysqlx::Crud::TABLE);
 
 		add_columns(columns,num_of_columns);
@@ -174,12 +176,12 @@ struct st_xmysqlnd_crud_table_op__update
 	std::vector<Mysqlx::Datatypes::Scalar*> bound_values;
 	uint32_t ps_message_id;
 
-	st_xmysqlnd_crud_table_op__update(const MYSQLND_CSTRING & schema,
-										   const MYSQLND_CSTRING & object_name) :
+	st_xmysqlnd_crud_table_op__update(const util::string& schema,
+										   const util::string_view& object_name) :
 		ps_message_id{ 0 }
 	{
-		message.mutable_collection()->set_schema(schema.s, schema.l);
-		message.mutable_collection()->set_name(object_name.s, object_name.l);
+		message.mutable_collection()->set_schema(schema.c_str(), schema.length());
+		message.mutable_collection()->set_name(object_name.data(), object_name.length());
 		message.set_data_model(Mysqlx::Crud::TABLE);
 	}
 
@@ -194,12 +196,12 @@ struct st_xmysqlnd_crud_table_op__delete
 	std::vector<Mysqlx::Datatypes::Scalar*> bound_values;
 	uint32_t ps_message_id;
 
-	st_xmysqlnd_crud_table_op__delete(const MYSQLND_CSTRING & schema,
-								const MYSQLND_CSTRING & object_name) :
+	st_xmysqlnd_crud_table_op__delete(const util::string& schema,
+								const util::string_view& object_name) :
 		ps_message_id{ 0 }
 	{
-		message.mutable_collection()->set_schema(schema.s, schema.l);
-		message.mutable_collection()->set_name(object_name.s, object_name.l);
+		message.mutable_collection()->set_schema(schema.c_str(), schema.length());
+		message.mutable_collection()->set_name(object_name.data(), object_name.length());
 		message.set_data_model(Mysqlx::Crud::TABLE);
 	}
 
