@@ -28,6 +28,8 @@
 
 #include "util/strings.h"
 
+#include <optional>
+
 namespace mysqlx {
 
 namespace drv {
@@ -38,12 +40,10 @@ class xmysqlnd_session_data;
 struct st_xmysqlnd_stmt_result;
 struct st_xmysqlnd_stmt_result_meta;
 struct st_xmysqlnd_stmt_execution_state;
-struct st_xmysqlnd_warning_list;
+class xmysqlnd_warning_list;
 struct st_xmysqlnd_level3_io;
 struct st_xmysqlnd_pb_message_shell;
 
-MYSQLND_CSTRING xmysqlnd_field_type_name(const unsigned int type);
-
 struct Message_context
 {
 	MYSQLND_VIO* vio;
@@ -56,21 +56,21 @@ struct Message_context
 
 struct st_xmysqlnd_on_warning_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const enum xmysqlnd_stmt_warning_level level, const unsigned int code, const MYSQLND_CSTRING message);
+	const enum_hnd_func_status (*handler)(void * context, const enum xmysqlnd_stmt_warning_level level, const unsigned int code, const util::string_view& message);
 	void * ctx;
 };
 
 
 struct st_xmysqlnd_on_error_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const unsigned int code, const MYSQLND_CSTRING sql_state, const MYSQLND_CSTRING message);
+	const enum_hnd_func_status (*handler)(void * context, const unsigned int code, const util::string_view& sql_state, const util::string_view& message);
 	void * ctx;
 };
 
 
 struct st_xmysqlnd_on_session_var_change_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const MYSQLND_CSTRING name, const zval * value);
+	const enum_hnd_func_status (*handler)(void * context, const util::string_view& name, const zval * value);
 	void * ctx;
 };
 
@@ -83,7 +83,7 @@ struct st_xmysqlnd_msg__capabilities_get
 									  zval * capabilities);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__capabilities_get* const msg,
-								  const struct st_xmysqlnd_on_error_bind on_error);
+								  const st_xmysqlnd_on_error_bind on_error);
 
 	Message_context msg_ctx;
 	st_xmysqlnd_on_error_bind on_error;
@@ -100,7 +100,7 @@ struct st_xmysqlnd_msg__capabilities_set
 									  zval* return_value);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__capabilities_set* const msg,
-								  const struct st_xmysqlnd_on_error_bind on_error);
+								  const st_xmysqlnd_on_error_bind on_error);
 	Message_context msg_ctx;
 	st_xmysqlnd_on_error_bind on_error;
 	zval* return_value_zval;
@@ -109,7 +109,7 @@ struct st_xmysqlnd_msg__capabilities_set
 
 struct st_xmysqlnd_on_auth_continue_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const MYSQLND_CSTRING input, MYSQLND_STRING * output);
+	const enum_hnd_func_status (*handler)(void * context, const util::string_view& input, util::string* output);
 	void * ctx;
 };
 
@@ -123,18 +123,18 @@ struct st_xmysqlnd_on_client_id_bind
 struct st_xmysqlnd_msg__auth_start
 {
 	enum_func_status (*send_request)(st_xmysqlnd_msg__auth_start* msg,
-									 const MYSQLND_CSTRING auth_mech_name,
-									 const MYSQLND_CSTRING auth_data);
+									 const util::string_view& auth_mech_name,
+									 const util::string_view& auth_data);
 
 	enum_func_status (*read_response)(st_xmysqlnd_msg__auth_start* msg,
 									  zval * auth_start_response);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__auth_start* const msg,
-								  const struct st_xmysqlnd_on_auth_continue_bind on_auth_continue,
-								  const struct st_xmysqlnd_on_warning_bind on_warning,
-								  const struct st_xmysqlnd_on_error_bind on_error,
-								  const struct st_xmysqlnd_on_client_id_bind on_client_id,
-								  const struct st_xmysqlnd_on_session_var_change_bind on_session_var_change);
+								  const st_xmysqlnd_on_auth_continue_bind on_auth_continue,
+								  const st_xmysqlnd_on_warning_bind on_warning,
+								  const st_xmysqlnd_on_error_bind on_error,
+								  const st_xmysqlnd_on_client_id_bind on_client_id,
+								  const st_xmysqlnd_on_session_var_change_bind on_session_var_change);
 
 	Message_context msg_ctx;
 	st_xmysqlnd_on_auth_continue_bind on_auth_continue;
@@ -151,11 +151,11 @@ struct st_xmysqlnd_meta_field_create_bind
 	void * ctx;
 };
 
-typedef enum_func_status (*func_xmysqlnd_wireprotocol__row_field_decoder)(const MYSQLND_CSTRING buffer, const st_xmysqlnd_result_field_meta* const field_meta, const unsigned int idx, zval * out_zv);
+typedef enum_func_status (*func_xmysqlnd_wireprotocol__row_field_decoder)(const util::string_view& buffer, const st_xmysqlnd_result_field_meta* const field_meta, const unsigned int idx, zval * out_zv);
 
 struct st_xmysqlnd_on_row_field_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const MYSQLND_CSTRING buffer, const unsigned int idx, const func_xmysqlnd_wireprotocol__row_field_decoder decoder);
+	const enum_hnd_func_status (*handler)(void * context, const util::string_view& buffer, const unsigned int idx, const func_xmysqlnd_wireprotocol__row_field_decoder decoder);
 	void * ctx;
 };
 
@@ -174,7 +174,7 @@ struct st_xmysqlnd_on_execution_state_change_bind
 
 struct st_xmysqlnd_on_generated_doc_ids_bind
 {
-	const enum_hnd_func_status (*handler)(void * context, const MYSQLND_STRING id);
+	const enum_hnd_func_status (*handler)(void * context, const util::string& id);
 	void * ctx;
 };
 
@@ -226,20 +226,20 @@ struct st_xmysqlnd_result_set_reader_ctx
 struct st_xmysqlnd_msg__sql_stmt_execute
 {
 	enum_func_status (*send_execute_request)(st_xmysqlnd_msg__sql_stmt_execute* msg,
-											 const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											 const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__sql_stmt_execute* const msg,
-								  const struct st_xmysqlnd_meta_field_create_bind create_meta_field,
-								  const struct st_xmysqlnd_on_row_field_bind on_row_field,
-								  const struct st_xmysqlnd_on_meta_field_bind on_meta_field,
-								  const struct st_xmysqlnd_on_warning_bind on_warning,
-								  const struct st_xmysqlnd_on_error_bind on_error,
-								  const struct st_xmysqlnd_on_generated_doc_ids_bind on_generated_doc_ids,
-								  const struct st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
-								  const struct st_xmysqlnd_on_session_var_change_bind on_session_var_change,
-								  const struct st_xmysqlnd_on_trx_state_change_bind on_trx_state_change,
-								  const struct st_xmysqlnd_on_stmt_execute_ok_bind on_stmt_execute_ok,
-								  const struct st_xmysqlnd_on_resultset_end_bind on_resultset_end);
+								  const st_xmysqlnd_meta_field_create_bind create_meta_field,
+								  const st_xmysqlnd_on_row_field_bind on_row_field,
+								  const st_xmysqlnd_on_meta_field_bind on_meta_field,
+								  const st_xmysqlnd_on_warning_bind on_warning,
+								  const st_xmysqlnd_on_error_bind on_error,
+								  const st_xmysqlnd_on_generated_doc_ids_bind on_generated_doc_ids,
+								  const st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
+								  const st_xmysqlnd_on_session_var_change_bind on_session_var_change,
+								  const st_xmysqlnd_on_trx_state_change_bind on_trx_state_change,
+								  const st_xmysqlnd_on_stmt_execute_ok_bind on_stmt_execute_ok,
+								  const st_xmysqlnd_on_resultset_end_bind on_resultset_end);
 
 
 	enum_func_status (*read_response)(st_xmysqlnd_msg__sql_stmt_execute* const msg,
@@ -262,7 +262,7 @@ struct st_xmysqlnd_msg__session_reset
 
 	st_xmysqlnd_on_error_bind on_error;
 
-	boost::optional<bool> keep_open;
+	std::optional<bool> keep_open;
 };
 
 struct st_xmysqlnd_msg__session_close
@@ -351,12 +351,12 @@ struct st_xmysqlnd_result_ctx
 struct st_xmysqlnd_msg__collection_add
 {
 	enum_func_status(*send_request)(st_xmysqlnd_msg__collection_add* msg,
-						const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+						const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status(*read_response)(st_xmysqlnd_msg__collection_add* msg);
 
 	enum_func_status(*init_read)(st_xmysqlnd_msg__collection_add* const msg,
-		const struct st_xmysqlnd_on_error_bind on_error);
+		const st_xmysqlnd_on_error_bind on_error);
 
 	Message_context msg_ctx;
 
@@ -366,16 +366,16 @@ struct st_xmysqlnd_msg__collection_add
 struct st_xmysqlnd_msg__table_insert
 {
 	enum_func_status(*send_insert_request)(st_xmysqlnd_msg__table_insert* msg,
-											const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status(*read_response)(st_xmysqlnd_msg__table_insert* msg);
 
 	enum_func_status(*init_read)(st_xmysqlnd_msg__table_insert* const msg,
-		const struct st_xmysqlnd_on_warning_bind on_warning,
-		const struct st_xmysqlnd_on_error_bind on_error,
-		const struct st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
-		const struct st_xmysqlnd_on_session_var_change_bind on_session_var_change,
-		const struct st_xmysqlnd_on_trx_state_change_bind on_trx_state_change);
+		const st_xmysqlnd_on_warning_bind on_warning,
+		const st_xmysqlnd_on_error_bind on_error,
+		const st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
+		const st_xmysqlnd_on_session_var_change_bind on_session_var_change,
+		const st_xmysqlnd_on_trx_state_change_bind on_trx_state_change);
 
 	struct st_xmysqlnd_result_ctx result_ctx;
 };
@@ -383,12 +383,12 @@ struct st_xmysqlnd_msg__table_insert
 struct st_xmysqlnd_msg__prepare_prepare
 {
 	enum_func_status(*send_prepare_request)(st_xmysqlnd_msg__prepare_prepare* msg,
-											const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status(*read_response)(st_xmysqlnd_msg__prepare_prepare* msg);
 
 	enum_func_status(*init_read)(st_xmysqlnd_msg__prepare_prepare* const msg,
-		const struct st_xmysqlnd_on_error_bind on_error);
+		const st_xmysqlnd_on_error_bind on_error);
 
 	Message_context msg_ctx;
 
@@ -398,12 +398,12 @@ struct st_xmysqlnd_msg__prepare_prepare
 struct st_xmysqlnd_msg__prepare_execute
 {
 	enum_func_status(*send_execute_request)(st_xmysqlnd_msg__prepare_execute* msg,
-											const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status(*read_response)(st_xmysqlnd_msg__prepare_execute* msg);
 
 	enum_func_status(*init_read)(st_xmysqlnd_msg__prepare_execute* const msg,
-		const struct st_xmysqlnd_on_error_bind on_error);
+		const st_xmysqlnd_on_error_bind on_error);
 
 	Message_context msg_ctx;
 
@@ -414,15 +414,15 @@ struct st_xmysqlnd_msg__prepare_execute
 struct st_xmysqlnd_msg__collection_ud
 {
 	enum_func_status (*send_update_request)(st_xmysqlnd_msg__collection_ud* msg,
-											const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status (*send_delete_request)(st_xmysqlnd_msg__collection_ud* msg,
-											const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+											const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status (*read_response)(st_xmysqlnd_msg__collection_ud* msg);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__collection_ud* const msg,
-								  const struct st_xmysqlnd_on_error_bind on_error);
+								  const st_xmysqlnd_on_error_bind on_error);
 
 	Message_context msg_ctx;
 
@@ -434,21 +434,21 @@ struct st_xmysqlnd_msg__collection_ud
 struct st_xmysqlnd_msg__collection_read
 {
 	enum_func_status (*send_read_request)(st_xmysqlnd_msg__collection_read* msg,
-										  const struct st_xmysqlnd_pb_message_shell pb_message_shell);
+										  const st_xmysqlnd_pb_message_shell pb_message_shell);
 
 	enum_func_status (*read_response_result)(st_xmysqlnd_msg__collection_read* msg);
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__collection_read* const msg,
-								  const struct st_xmysqlnd_meta_field_create_bind create_meta_field,
-								  const struct st_xmysqlnd_on_row_field_bind on_row_field,
-								  const struct st_xmysqlnd_on_meta_field_bind on_meta_field,
-								  const struct st_xmysqlnd_on_warning_bind on_warning,
-								  const struct st_xmysqlnd_on_error_bind on_error,
-								  const struct st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
-								  const struct st_xmysqlnd_on_session_var_change_bind on_session_var_change,
-								  const struct st_xmysqlnd_on_trx_state_change_bind on_trx_state_change,
-								  const struct st_xmysqlnd_on_stmt_execute_ok_bind on_stmt_execute_ok,
-								  const struct st_xmysqlnd_on_resultset_end_bind on_resultset_end);
+								  const st_xmysqlnd_meta_field_create_bind create_meta_field,
+								  const st_xmysqlnd_on_row_field_bind on_row_field,
+								  const st_xmysqlnd_on_meta_field_bind on_meta_field,
+								  const st_xmysqlnd_on_warning_bind on_warning,
+								  const st_xmysqlnd_on_error_bind on_error,
+								  const st_xmysqlnd_on_execution_state_change_bind on_execution_state_change,
+								  const st_xmysqlnd_on_session_var_change_bind on_session_var_change,
+								  const st_xmysqlnd_on_trx_state_change_bind on_trx_state_change,
+								  const st_xmysqlnd_on_stmt_execute_ok_bind on_stmt_execute_ok,
+								  const st_xmysqlnd_on_resultset_end_bind on_resultset_end);
 
 	struct st_xmysqlnd_result_set_reader_ctx reader_ctx;
 };
